#
# spec file for package python-funcparserlib
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-funcparserlib
Version:        1.0.1
Release:        1.10
Summary:        Recursive descent parsing library based on functional combinators
License:        MIT
Group:          Development/Languages/Python
URL:            https://github.com/vlasovskikh/funcparserlib
Source:         https://github.com/vlasovskikh/funcparserlib/archive/refs/tags/%{version}.tar.gz#/funcparserlib-%{version}-gh.tar.gz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module poetry-core}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module six}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildArch:      noarch
%python_subpackages

%description
The primary focus of funcparserlib is parsing little languages or external
DSLs (domain specific languages).

Parsers made with funcparserlib are pure-Python LL(*) parsers. It means that
it's very easy to write parsers without thinking about lookaheads and other
hardcore parsing stuff. However, recursive descent parsing is a rather
low method compared to LL(k) or LR(k) algorithms. Still, parsing with
funcparserlib is at least twice faster than PyParsing, a very popular library
for Python.

%prep
%setup -q -n funcparserlib-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%files %{python_files}
%license LICENSE
%doc README.md
%{python_sitelib}/funcparserlib
%{python_sitelib}/funcparserlib-%{version}*-info

%changelog
* Tue Nov  8 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to 1.0.1
  * Added support for Python 3.11
* Mon Oct 17 2022 Steve Kowalik <steven.kowalik@suse.com>
- Re-add missing BuildRequires on six.
* Thu Aug  4 2022 Ben Greiner <code@bnavigator.de>
- Update to 1.0.0
  * The stable 1.0.0 release freezes the API of funcparserlib 0.3.6
    which was released on 2013-05-02, with a few bug fixes and
    small features.
  * Added support for Python 3.10
  * Added support for Python 3.9 (#63) (Thanks to @pkulev)
  * Added support for Python 3.8
  * Added -p (the same as skip(p)) with more strict type hints for
  - p and p1 + p2
  * Added tok(type[, value]) for more compact grammars, better
    error messages
  * Added TokenSpec(type, pattern[, flags]) to simplify the use of
    make_tokenizer()
  * Added type hints for the public API
  * Added the new library homepage with the new Getting Started
    guide and the new API reference
  * Parse exceptions now show expected tokens and grammar rules at
    the stopped position (#52)
  * Dropped support for Python 3.4, 3.5, 3.6 (end of life)
  * Dropped support for Python 2.5, 2.6, 3.3 (end of life),
    modernized code for Python 3 to run without obsolete 2to3 (#57)
    (Thanks to @jdufresne)
  * Removed documentation and unit tests from the distribution
  * Switched from setuptools to Poetry
  * Switched to poetry-core for lighter PEP 517 builds (#73)
    (Thanks to @fabaff)
  * Fixed TypeError in oneplus when applying it parser + parser
    (#66) (Thanks to @martica)
  * Fixed AttributeError when comparing Token objects to None (#58)
    (Thanks to @Halolegend94)
  * Fixed doctests in the tutorial (#49)
  * Fixed several cases of wrong expected tokens in error messages
- Drop no2to3.patch
* Tue Mar  1 2022 Dirk Müller <dmueller@suse.com>
- add no2to3.patch for compatibility with newer setuptools
* Mon Nov  8 2021 Dirk Müller <dmueller@suse.com>
- add missing six dependency
* Wed Sep  9 2020 pgajdos@suse.com
- new upstream url
* Sun Aug 16 2020 John Vandenberg <jayvdb@gmail.com>
- Use modernize to fix Python 2 only syntax in runtime code
- Re-activate test suite by switching from nose to pytest
- Tidy spec
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Wed Apr 19 2017 toddrme2178@gmail.com
- Source must be https.
* Wed Apr 19 2017 toddrme2178@gmail.com
- Implement single-spec version.
* Sun Mar 13 2016 dmueller@suse.com
- add license
* Thu Oct 31 2013 mcihar@suse.cz
- Initial packaging
